@@ -1154,7 +1154,11 @@ class Automation:
             logger.error('No data returned for this API call. %s', response.request.url)
             return response_status, pandas.DataFrame()
 
-        df = pandas.read_json(response.text)
+        # We need to wrap json results in StringIO when stringified JSON is present in the response.
+        # Symptoms of not doing this are: ValueError: Unexpected character found when decoding object value
+        # and incorrect suggestion in the error on installing a package called 'fsspec'
+        # Installing 'fsspec' package will not solve the issue.
+        df = pandas.read_json(StringIO(response.text))
         df.columns = _column_name_cap(df.columns)
         return df
 
